@@ -3,6 +3,8 @@
 
 def true_false_caster(val):
     """Casts 'TRUE', 'true', etc. to True, all other strings to False."""
+    if isinstance(val, bool):
+        return val
     try:
         return val.lower() == 'true'
     except AttributeError:
